@@ -2,10 +2,10 @@ spinner_plot <- function(probs, ...){
    args <- list(...)
    if("values" %in% names(args))
      values <- args$values else
-     values <- 1:length(probs)
-   Spin <- factor(values)
+     values <- seq_along(probs)
+   Region <- factor(values)
    y <- probs
-   df <- data.frame(Spin, y)
+   df <- data.frame(Region, y)
    TH <- theme(
      plot.title = element_text(
        colour = "blue",
@@ -15,7 +15,7 @@ spinner_plot <- function(probs, ...){
        angle = 0
      )
    )
-   p <- ggplot(df, aes(1, y, fill=Spin)) +
+   p <- ggplot(df, aes(1, y, fill=Region)) +
    geom_bar(stat="identity") +
    coord_polar(theta = "y", direction=1) +
      xlab("") + ylab("") +
